# -*- coding: utf-8 -*-
"""
Created on Thu Jan 31 15:59:24 2019

@author: bgregor
"""

import numpy as np
import scipy.ndimage as nd

# A standard Anaconda install won't have
# OpenCV available
# In Navigator: Environments --> click Not Installed --> search opencv
#                           Check "opencv" and the Apply button
# From the command line:
#        conda install -c conda-forge opencv    

import cv2

# Fetch the image from the web
# This is a standard Python 3.6+ library
import requests
# read binary data like it's a file.
import tempfile
import os

img_resp = requests.get('https://upload.wikimedia.org/wikipedia/commons/thumb/2/2f/Boston_University_College_of_Arts_and_Sciences.jpg/1024px-Boston_University_College_of_Arts_and_Sciences.jpg')
# Write it to a file in a temporary directory
# The temp directory will automatically be deleted.
with tempfile.TemporaryDirectory() as tmpdirname:
    fname = os.path.join(tmpdirname,'Boston_University_Bridge_aerial.JPG')
    with open(fname,'w+b') as f:
        f.write(img_resp.content)
        f.close()
    # Read the image with OpenCV
    img = cv2 .imread(fname,cv2.IMREAD_COLOR)
    # all done, delete the file.
    os.unlink(fname)
    




# For timing convenience, do the scipy filtering
# in a function since it must be applied channel-by-channel:
def scipy_gaussian(img,filtered):
    for i in range(img.shape[2]):
        filtered[:, :, i] = nd.gaussian_filter(img[:, :, i], 5)

def scipy_median(img,filtered):
    for i in range(img.shape[2]):
        filtered[:, :, i] = nd.median_filter(img[:, :, i], 9)

# Create an ndarray to store the filtered images
filtered = np.ndarray(img.shape,img.dtype)
# Time them!  Run these commands in IPython
#  %timeit scipy_gaussian(img,filtered)
#  %timeit scipy_median(img,filtered)
#  %timeit filtered = cv2.GaussianBlur(img,(0,0),5)
#  %timeit filtered = cv2.medianBlur(img,9)