# -*- coding: utf-8 -*-
"""
Created on Tue Oct  1 12:56:11 2019

MANUAL timing of function calls.

@author: bgregor
"""
import numpy as np

import time


def row_by_row(A,x):
    ''' compute x = A*x row-by-row '''
    rows = x.shape[0]
    for i in range(rows):
        x[i,:] = x[i,:] * A
    return x

def col_by_col(A,x):
    ''' compute x = A*x col_by_col '''
    cols = x.shape[1]
    for i in range(cols):
        x[:,i] = x[:,i] * A
    return x

def timer(fun, A, x):
    ''' Run one of the functions above and return 
        the elapsed time in milliseconds'''
    start_t = time.perf_counter()
    fun(A,x)
    end_t = time.perf_counter()
    # the diff is in seconds, convert to ms
    return (end_t - start_t) * 1000
    

if __name__=='__main__':
    # Pick a number to set the size of the matrix
    # Can't see a timing difference?  Make this bigger,
    # say 1000 or 10000
    mat_size = 200
    # Let's just multiply by 2.
    scaling_value = 2.0

    # Create the matrix.
    mat = np.ones([mat_size,mat_size])
    # Run row-by-row
    rr_time = timer(row_by_row, scaling_value, mat)
    print(f'row_by_row: {rr_time:4.4} msec')

    # and laboriously repeat...
    cc_time = timer(col_by_col, scaling_value, mat)
    print('If the matrix size is large enough, col-by-col will be slower')
    print(f'col_by_col: {cc_time:4.4} msec')
    
   

