# -*- coding: utf-8 -*-
"""
Playing around with Numpy and random numbers
"""
import numpy as np

# Make an RNG object with a random seed
rng = np.random.default_rng()

# an ndarray of the integers 0-5
a = np.arange(6)
print(f'a: {a}')
# shuffle a in place 
rng.shuffle(a)
print(f'a after shuffling: {a}')


# Create an rng object from a specified seed
rng2 = np.random.default_rng(seed=100)
# the RNG sequence is deterministic, so 
# everyone using the same seed and algorithm
# gets the same sequence. Get 4 numbers 
# from a Gaussian distribution.  Sampling functions
# typically take a size argument to set the number of
# samples to return.
norms = rng2.normal(size=4)
print(f'norms: {norms}')
# array([-1.15754965,  0.2897558 ,  0.78085407,  0.54397364])

# You could also use a for loop, although this is 
# MUCH slower
more_norms = np.zeros(4)
for i in range(more_norms.shape[0]):
    # the size argument defauls to 1
    more_norms[i] = rng2.normal() 


# Simulate rolling dice
# Check the docs:
#   help(rng.integers) 

# Get some random integers 1-5
dice_roll = rng.integers(1,high=6,size=10)
# no we want 1-6 for a 6-sided die, 
# so add the endpoint argument
dice_roll = rng.integers(1,high=6,size=10,endpoint=True)
print(f'some dice rolls: {dice_roll}')

