import numpy as np
from scipy.optimize import minimize
from matplotlib import pyplot as plt

# A function that computes a parabola,
# aka a quadratic.
def parabola(x,A,B,C):
    return A * x**2 + B * x + C

# Set the A,B, and C constants:
A = 3.0
B = 1.1
C = -1.1

# Pick a starting value of x for the minimize function
# to use.  Depending on the function to be minimized this can
# be difficult to select.  For the parabola() function anything
# will do. 
x0 = 1.0
# The name of the function to minimize is the# first 
# argument to the scipy.optimize.minimize function. 
# The x value is automatically the 1st argument to the parabola()
# call.  The other arguments are set using the args tuple.  
result = minimize(parabola, x0, args=(A,B,C))
# result is a dictionary: 
#      fun: -1.2008333333333334
# hess_inv: array([[0.16666667]])
#      jac: array([1.49011612e-08])
#  message: 'Optimization terminated successfully.'
#     nfev: 9
#      nit: 2
#     njev: 3
#   status: 0
#  success: True
#        x: array([-0.18333334])

# Plot it! Make some sample points in x 
xp = np.linspace(-2,2,100)
yp = parabola(xp,A,B,C)
# And the solution's x point that gives the
# minimum value of the function 
x_min = result['x'][0]
y_min = parabola(x_min,A,B,C)
plt.plot(xp,yp,x_min,y_min,'ro')
plt.show()
